"""
Type annotations for mobile service client.

[Open documentation](./client.md)

Usage::

    ```python
    import boto3
    from mypy_boto3_mobile import MobileClient

    client: MobileClient = boto3.client("mobile")
    ```
"""
import sys
from typing import IO, Any, Dict, Type, Union, overload

from botocore.client import ClientMeta

from mypy_boto3_mobile.paginator import ListBundlesPaginator, ListProjectsPaginator

from .literals import Platform
from .type_defs import (
    CreateProjectResultTypeDef,
    DeleteProjectResultTypeDef,
    DescribeBundleResultTypeDef,
    DescribeProjectResultTypeDef,
    ExportBundleResultTypeDef,
    ExportProjectResultTypeDef,
    ListBundlesResultTypeDef,
    ListProjectsResultTypeDef,
    UpdateProjectResultTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("MobileClient",)


class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str

    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str


class Exceptions:
    AccountActionRequiredException: Type[BotocoreClientError]
    BadRequestException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    InternalFailureException: Type[BotocoreClientError]
    LimitExceededException: Type[BotocoreClientError]
    NotFoundException: Type[BotocoreClientError]
    ServiceUnavailableException: Type[BotocoreClientError]
    TooManyRequestsException: Type[BotocoreClientError]
    UnauthorizedException: Type[BotocoreClientError]


class MobileClient:
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Client)
    [Show boto3-stubs documentation](./client.md)
    """

    meta: ClientMeta
    exceptions: Exceptions

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Client.can_paginate)
        [Show boto3-stubs documentation](./client.md#can-paginate)
        """

    def create_project(
        self,
        name: str = None,
        region: str = None,
        contents: Union[bytes, IO[bytes]] = None,
        snapshotId: str = None,
    ) -> CreateProjectResultTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Client.create_project)
        [Show boto3-stubs documentation](./client.md#create-project)
        """

    def delete_project(self, projectId: str) -> DeleteProjectResultTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Client.delete_project)
        [Show boto3-stubs documentation](./client.md#delete-project)
        """

    def describe_bundle(self, bundleId: str) -> DescribeBundleResultTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Client.describe_bundle)
        [Show boto3-stubs documentation](./client.md#describe-bundle)
        """

    def describe_project(
        self, projectId: str, syncFromResources: bool = None
    ) -> DescribeProjectResultTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Client.describe_project)
        [Show boto3-stubs documentation](./client.md#describe-project)
        """

    def export_bundle(
        self, bundleId: str, projectId: str = None, platform: Platform = None
    ) -> ExportBundleResultTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Client.export_bundle)
        [Show boto3-stubs documentation](./client.md#export-bundle)
        """

    def export_project(self, projectId: str) -> ExportProjectResultTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Client.export_project)
        [Show boto3-stubs documentation](./client.md#export-project)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Client.generate_presigned_url)
        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
        """

    def list_bundles(
        self, maxResults: int = None, nextToken: str = None
    ) -> ListBundlesResultTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Client.list_bundles)
        [Show boto3-stubs documentation](./client.md#list-bundles)
        """

    def list_projects(
        self, maxResults: int = None, nextToken: str = None
    ) -> ListProjectsResultTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Client.list_projects)
        [Show boto3-stubs documentation](./client.md#list-projects)
        """

    def update_project(
        self, projectId: str, contents: Union[bytes, IO[bytes]] = None
    ) -> UpdateProjectResultTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Client.update_project)
        [Show boto3-stubs documentation](./client.md#update-project)
        """

    @overload
    def get_paginator(self, operation_name: Literal["list_bundles"]) -> ListBundlesPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Paginator.ListBundles)[Show boto3-stubs documentation](./paginators.md#listbundlespaginator)
        """

    @overload
    def get_paginator(self, operation_name: Literal["list_projects"]) -> ListProjectsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/mobile.html#Mobile.Paginator.ListProjects)[Show boto3-stubs documentation](./paginators.md#listprojectspaginator)
        """
